<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Niveau %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Intet cover</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Indtast den nye endelse</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Lav ny endelse</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Afbryd</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Mappen hvor videoerne ligger</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Denne mappe skal være oprettet, og mythtv brugeren har kun brug for læserettigheder til mappen.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Start voksen niveau</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - Højest</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Lavest</translation>
    </message>
    <message>
        <source>2</source>
        <translation type="obsolete">2</translation>
    </message>
    <message>
        <source>3</source>
        <translation type="obsolete">3</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>Voksen kontrol kode</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Vis ukendte fil typer</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Afspiler opsætning</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Voksen kode</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Intet cover</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>None</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation type="obsolete">Ukendt Rating</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Standard afspiller</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>Nye filer vises som standard</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>Kommando til at søge film data</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>Kommando til at søge efter film billeder</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>Kommando til at udtrække film data</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>Mappen hvor film billederne ligger</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>Video Manager</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>Kunne ikke hente billeder</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>Der findes billeder til denne film, men Myth kunne ikke hente dem indenfor den givne tid.</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>Standard visning</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galleri</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Browser</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>Lister</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>Aggressiv voksen kontrol</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>Antal rækker der vises</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>Antal kolonner der vises</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>Vis titel under billede</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation>Hvis aktiv, vil teksten gøre billedet mindre.</translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>Behold aspektet på miniature billederne</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation>Hvis aktiv, beholder miniature billederne deres oprindelige aspekt. Hvis ikke aktiv, scaléres de til at passe til bagrundsikonerne.</translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>Video galleri</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Browser browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (1/2)</source>
        <translation>Generel Opsætning (1/2)</translation>
    </message>
    <message>
        <source>General Settings (2/2)</source>
        <translation>Generel Opsætning (2/2)</translation>
    </message>
    <message>
        <source>Video List Loads Video Meta Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorting ignores case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, case is ignored when sorting entries in a view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show folders for database views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, sub folders of your video directory will be shown in supported views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image cache size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting determines the number of images MythVideo will cache for views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>^(The |A |An )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Alt</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Nej</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished">År</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished">Bruger Rating</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished">Længde</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Instruktør:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Udgivet:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Klassifikation:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Voksen niveau:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Længde:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Resumé:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Filnavn:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Omslagsfil:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>Henter information...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ leder efter ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Indtast IMDB #</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>Indlæser...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Ingen videoer fundet</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Instrueret af:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Fil:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Afspiller:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>IMDB nr.:</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>PL </translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Endelse:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Brug def. afspiller:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignorer:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Ændre video information</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Voksen kontrol:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Fil der skal afspilles bagefter:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Covert grafik:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Unik afspiller kommando:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/sti/til/billede.jpg</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Filtrér film liste</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Kategori :</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Genre :</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>Land :</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>År :</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Længde :</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Bruger Rating :</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Sorter med :</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>SELECT: Ændre</translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>Voksen</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>År</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Længde</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Bruger Rating</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - menu</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Op/Ned, Side Op/Ned: Bladre   MENU: Options   INFO: Action Menu</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Afspil fil efter denne:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 af %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Ingen film</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Ingen ratings tilgængelig</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutter</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Se denne video</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vis fuldt resume</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrér visning</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Afbryd</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Skift til Browse visning</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Skift til Galleri Visning</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Skift til Liste visning</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Vælg funktion</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Voksen kode:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Resultat af dette filter : %1 film</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Resultat af dette filter: Ingen film</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ukendt</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="obsolete">Alt</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Gem som standard</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>Filtrér visning</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Se denne video</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vis fuldt resume</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Vis detajler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Afbryd</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutter</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Nej</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Intet cover</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ukendt</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Intet</translation>
    </message>
    <message>
        <source>NR</source>
        <translation type="obsolete">Nr</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>sletning fejlede</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Vælg funktion</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Rediger Metadata</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Søg IMDB</translation>
    </message>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Indtast IMDB nr</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Nulstil Metadata</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Fjern film</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrér Visning</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Afbryd</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>Slet denne fil?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Ingen ratings tilgængelig.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutter</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Voksen kode:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Vælg funktion</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Vis denne video</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vis fuldt resume</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtrér visning</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Skift til Browse visning</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Skift til Galleri Visning</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Afbryd</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
